@@ -1,5 +1,5 @@
 package Util::Medley::Module::Overview;
-$Util::Medley::Module::Overview::VERSION = '0.035';
+$Util::Medley::Module::Overview::VERSION = '0.036';
 use Modern::Perl;
 use Moose;
 use namespace::autoclean;
@@ -17,7 +17,7 @@ Util::Medley::Module::Overview
 
 =head1 VERSION
 
-version 0.035
+version 0.036
 
 =cut
 
@@ -298,11 +298,10 @@ method getPublicMethods {
 	my @public;
 	foreach my $method ( @{ $self->_getMyMethods } ) {
 
-       $method = $self->_scrubParens($method);
-       
 		# moose objects seems to end up with a public method called meta()
 		# here we skip it if we encounter it.
-		if ( $method ne 'meta' ) {
+	    my $scrubbed = $self->_scrubParens($method);
+		if ( $scrubbed ne 'meta' ) {
 
 			if ( $method !~ /^_/ ) {
 				push @public, $method;
